@@ -2,8 +2,8 @@
 #
 # Apache::Session
 # Apache persistent user sessions
-# Copyright(c) 1998, 1999, 2000, 2001, 2004 Jeffrey William Baker (jwbaker@acm.org)
-# Distribute under the Perl License
+# Copyright(c) 1998, 1999, 2000 Jeffrey William Baker (jwbaker@acm.org)
+# Distribute under the Artistic License
 #
 #############################################################################
 
@@ -13,30 +13,30 @@ Apache::Session - A persistence framework for session data
 
 =head1 SYNOPSIS
 
-  use Apache::Session::MySQL;
-
+  use Apache::Session::DBI;
+  
   my %session;
-
+  
   #make a fresh session for a first-time visitor
   tie %session, 'Apache::Session::MySQL';
 
   #stick some stuff in it
   $session{visa_number} = "1234 5678 9876 5432";
-
+  
   #get the session id for later use
   my $id = $session{_session_id};
-
+  
   #...time passes...
-
-  #get the session data back out again during some other request
+  
+  #get the session data back out again
   my %session;
   tie %session, 'Apache::Session::MySQL', $id;
-
-  validate($session{visa_number});
-
+  
+  &validate($session{visa_number});
+  
   #delete a session from the object store permanently
   tied(%session)->delete;
-
+  
 
 =head1 DESCRIPTION
 
@@ -49,14 +49,13 @@ altogether.
 Apache::Session consists of five components: the interface, the object store,
 the lock manager, the ID generator, and the serializer.  The interface is
 defined in Session.pm, which is meant to be easily subclassed.  The object
-store can be the filesystem, a Berkeley DB, a MySQL DB, an Oracle DB, a
-Postgres DB, Sybase, or Informix. Locking is done by lock files, semaphores, or
-the locking capabilities of the various databases.  Serialization is done via
-Storable, and optionally ASCII-fied via MIME or pack().  ID numbers are
-generated via MD5.  The reader is encouraged to extend these capabilities to
-meet his own requirements.
+store can be the filesystem, a Berkeley DB, a MySQL DB, or a Postgres DB.
+Locking is done by lock files, semaphores, or the locking capabilities of MySQL
+and Postgres.  Serialization is done via Storable, and optionally  ASCII-fied
+via MIME or pack().  ID numbers are generated via MD5.  The reader is
+encouraged to extend these capabilities to meet his own requirements.
 
-A derived class of Apache::Session is used to tie together the three following
+A derived class of Apache::Session is used to tie together the three
 components.  The derived class inherits the interface from Apache::Session, and
 specifies which store and locker classes to use.  Apache::Session::MySQL, for
 instance, uses the MySQL storage class and also the MySQL locking class. You
@@ -76,7 +75,7 @@ Get a new session using DBI:
 
  tie %session, 'Apache::Session::MySQL', undef,
     { DataSource => 'dbi:mysql:sessions' };
-
+    
 Restore an old session from the database:
 
  tie %session, 'Apache::Session::MySQL', $session_id,
@@ -94,7 +93,7 @@ Hey, how much easier could it get?
 =head2 Reading the session ID
 
 The session ID is the only magic entry in the session object,
-but anything beginning with an "_" is considered reserved for
+but anything beginning with a "_" is considered reserved for
 future use.
 
  my $id = $session{_session_id};
@@ -110,7 +109,7 @@ you would expect.  When you create a new session, Session immediately
 saves the session to the data store, or calls die() if it cannot.  It
 also obtains an exclusive lock on the session object.  If you retrieve
 an existing session, Session immediately restores the object from storage,
-or calls die() in case of an error.  Session also obtains a non-exclusive
+or calls die() in case of an error.  Session also obtains an non-exclusive
 lock on the session.
 
 As you put data into the session hash, Session squirrels it away for
@@ -168,7 +167,7 @@ some session handling basics.
 
 When you share data between Apache processes, you need to decide on a
 session ID number ahead of time and make sure that an object with that
-ID number is in your object store before starting your Apache.  How you
+ID number is in your object store before starting you Apache.  How you
 accomplish that is your own business.  I use the session ID "1".  Here
 is a short program in which we use Apache::Session to store out 
 database access information.
@@ -178,9 +177,9 @@ database access information.
  use DBI;
 
  use strict;
-
+  
  my %global_data;
-
+ 
  eval {
      tie %global_data, 'Apache::Session::File', 1,
         {Directory => '/tmp/sessiondata'};
@@ -193,9 +192,9 @@ database access information.
     $global_data{username}, $global_data{password}) || die $DBI::errstr;
 
  undef %global_data;
-
+ 
  #program continues...
-
+ 
 As shown in this example, you should undef or untie your session hash
 as soon as you are done with it.  This will free up any locks associated
 with your process.
@@ -207,10 +206,7 @@ is a rather religious topic among Apache users.  This example uses cookies.
 The implementation of a path info system is left as an exercise for the
 reader.
 
-Note that Apache::Session::Generate::ModUsertrack uses Apache's mod_usertrack
-cookies to generate and maintain session IDs.
-
- use Apache::Session::MySQL;
+ use Apache::Session::DBI;
  use Apache;
 
  use strict;
@@ -244,40 +240,16 @@ cookies to generate and maintain session IDs.
 =head1 SEE ALSO
 
 Apache::Session::MySQL, Apache::Session::Postgres, Apache::Session::File,
-Apache::Session::DB_File, Apache::Session::Oracle, Apache::Session::Sybase
+Apache::Session::DB_File
 
 The O Reilly book "Apache Modules in Perl and C", by Doug MacEachern and
 Lincoln Stein, has a chapter on keeping state.
 
-CGI::Session uses OO interface to do same thing. It is better maintained,
-but less possibilies.
-
-Catalyst::Plugin::Session - support of sessions in Catalyst
-
-Session - OO interface to Apache::Session
-
-=head1 LICENSE
-
-Same as Perl.
-
 =head1 AUTHORS
 
 Jeffrey Baker <jwbaker@acm.org> is the author of 
 Apache::Session.
 
-Tatsuhiko Miyagawa <miyagawa@bulknews.net> is the author of 
-Generate::ModUniqueID and Generate::ModUsertrack
-
-Erik Rantapaa <rantapaa@fanbuzz.com> found errors in both Lock::File
-and Store::File
-
-Bart Schaefer <schaefer@zanshin.com> notified me of a bug in 
-Lock::File.
-
-Chris Winters <cwinters@intes.net> contributed the Sybase code.
-
-Michael Schout <mschout@gkg.net> fixed a commit policy bug in 1.51.
-
 Andreas J. Koenig <andreas.koenig@anima.de> contributed valuable CPAN
 advice and also Apache::Session::Tree and Apache::Session::Counted.
 
@@ -301,21 +273,6 @@ storage-independent object interface with input from:
   Jules Bean <jmlb2@hermes.cam.ac.uk>
   Lincoln Stein <lstein@cshl.org>
 
-Jamie LeTaul <jletual@kmtechnologies.com> fixed file locking on Windows.
-
-Scott McWhirter <scott@surreytech.co.uk> contributed verbose error messages for
-file locking.
-
-Corris Randall <corris@line6.net> gave us the option to use any table name in
-the MySQL store.
-
-Oliver Maul <oliver.maul@ixos.de> updated the Sybase modules
-
-Innumerable users sent a patch for the reversed file age test in the file
-locking module.
-
-Langen Mike <mike.langen@tamedia.ch> contributed Informix modules.
-
 =cut
 
 package Apache::Session;
@@ -323,8 +280,7 @@ package Apache::Session;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '1.86_03';
-$VERSION = eval $VERSION;
+$VERSION = '1.50';
 
 #State constants
 #
@@ -400,17 +356,10 @@ sub TIEHASH {
 
     $self->populate;
 
-
     #If a session ID was passed in, this is an old hash.
     #If not, it is a fresh one.
 
-    if (defined $session_id  && $session_id) {
-        
-        #check the session ID for remote exploitation attempts
-        #this will die() on suspicious session IDs.        
-
-        &{$self->{validate}}($self);        
-        
+    if (defined $session_id) {
         if (exists $args->{Transaction} && $args->{Transaction}) {
             $self->acquire_write_lock;
         }
@@ -509,7 +458,7 @@ sub restore {
     &{$self->{unserialize}}($self);
     
     $self->{status} &= ($self->{status} ^ MODIFIED);
-    $self->{status} |= SYNCED;
+    $self->{status} |= SYNCED
 }
 
 sub save {
