@@ -2,7 +2,7 @@
 #
 # Apache::Session::Flex
 # Apache persistent user sessions stored however you want
-# Copyright(c) 2000, 2001 Jeffrey William Baker (jwbaker@acm.org)
+# Copyright(c) 2000 Jeffrey William Baker (jwbaker@acm.org)
 # Distribute under the Artistic License
 #
 ############################################################################
@@ -10,11 +10,13 @@
 package Apache::Session::Flex;
 
 use strict;
-use vars qw(@ISA $VERSION);
+use vars qw(@ISA $VERSION $incl);
 
-$VERSION = '1.01';
+$VERSION = '1.00';
 @ISA = qw(Apache::Session);
 
+$incl = {};
+
 use Apache::Session;
 
 sub populate {
@@ -25,29 +27,32 @@ sub populate {
     my $gen   = "Apache::Session::Generate::$self->{args}->{Generate}";
     my $ser   = "Apache::Session::Serialize::$self->{args}->{Serialize}";
 
-    for my $class ($store, $lock) {
-        unless ($class->can('new')) {
-            eval "require $class" || die $@;
-        }
+    if (!exists $incl->{$store}) {
+        eval "require $store" || die $@;
+        $incl->{$store} = 1;
     }
-
-    unless ($gen->can('validate')) {
+    
+    if (!exists $incl->{$lock}) {
+        eval "require $lock" || die $@;
+        $incl->{$lock} = 1;
+    }
+    
+    if (!exists $incl->{$gen}) {
         eval "require $gen" || die $@;
+        eval '$incl->{$gen} = \&' . $gen . '::generate' || die $@;
     }
-
-    unless ($ser->can('serialize')) {
+    
+    if (!exists $incl->{$ser}) {
         eval "require $ser" || die $@;
+        eval '$incl->{$ser}->[0] = \&' . $ser . '::serialize' || die $@;
+        eval '$incl->{$ser}->[1] = \&' . $ser . '::unserialize' || die $@;
     }
-
+    
     $self->{object_store} = new $store $self;
-    $self->{lock_manager} = new $lock  $self;
-    {
-        no strict 'refs';
-        $self->{generate}     = \&{$gen . '::generate'};
-        $self->{validate}     = \&{$gen . '::validate'};
-        $self->{serialize}    = \&{$ser . '::serialize'};
-        $self->{unserialize}  = \&{$ser . '::unserialize'};
-    }
+    $self->{lock_manager} = new $lock $self;
+    $self->{generate}     = $incl->{$gen};
+    $self->{serialize}    = $incl->{$ser}->[0];
+    $self->{unserialize}  = $incl->{$ser}->[1];
 
     return $self;
 }
@@ -63,14 +68,14 @@ Apache::Session::Flex - Specify everything at runtime
 =head1 SYNOPSIS
 
  use Apache::Session::Flex;
-
+ 
  tie %hash, 'Apache::Session::Flex', $id, {
     Store     => 'DB_File',
     Lock      => 'Null',
     Generate  => 'MD5',
     Serialize => 'Storable'
  };
-
+ 
  # or
 
  tie %hash, 'Apache::Session::Flex', $id, {
@@ -79,7 +84,7 @@ Apache::Session::Flex - Specify everything at runtime
     Generate  => 'MD5',
     Serialize => 'Base64'
  };
-
+ 
  # you decide!
 
 =head1 DESCRIPTION
@@ -110,7 +115,7 @@ There are many modules included in this distribution.  For each role, they are:
     Postgres
     DB_File
     File
-
+ 
  Lock:
     Null
     MySQL
@@ -118,12 +123,12 @@ There are many modules included in this distribution.  For each role, they are:
 
  Generate:
     MD5
-
+    
  Serialize:
     Storable
     Base64
     UUEncode
-
+   
 In addition to the arguments needed by this module, you must provide whatever
 arguments are expected by the backing store and lock manager that you are
 using.  Please see the documentation for those modules.
